==> cosmotech_supplychain-5.4.0.tar.gz: cosmotech_supplychain-5.4.0/Supplychain/Schema/default_values.py <==
parameters_default_values = {
    "Stock": {
        # "id",
        # "Label",
        "PlantName": "",
        "Step": "",
        "PartId": "",
        "MinimalStock": -1,
        "MaximalStock": None,
        # "InitialStock",
        # "InitialValue",
        # "IsInfinite",
        "PurchasingUnitCosts": {},
        "VariablePurchasingUnitCosts": {},
        "CO2UnitEmissions": {},
        "UnitIncomes": {},
        "BacklogWeight": 1,
        "MaximizationWeight": 0,
        "StockPolicy": "None",
        "SourcingPolicy": "Equidistribution",
        "DispatchPolicy": "DispatchProportions",
        "ReviewPeriod": 1,
        "FirstReview": 0,
        "Advance": 0,
        "Latitude": 0.0,
        "Longitude": 0.0,
        "IgnoreDownstreamRequiredQuantities": False,
        "SourcingLimit": "Capacity",
        "Tag": "",
        "InitialBacklog": 0,
        "OrderForEndOfTimeStep": True,
        "subdataset": "",
        "StorageUnitCosts": {},
        "OrderPoints": {},
        "OrderQuantities": {},
        "OrderUpToLevels": {},
        "SafetyQuantities": {},
        "CoverageHorizon": 0,
        "CoverageOffset": 0,
        "CoverageRate": 1,
        "Demands": {},
        "DemandUncertainties": {},
        "DemandWeights": {},
        "SalesForecasts": {},
        # "RetainProportions",
    },
    "Transport": {
        # "Label",
        # "source",
        # "target",
        # "Duration",
        "Priority": 0,
        "Mode": "",
        "subdataset": "",
        "CustomFees": {},
        "TransportUnitCosts": {},
        "CO2UnitEmissions": {},
        "ActualDurations": {},
        "MinimumOrderQuantities": {},
        "MultipleOrderQuantities": {},
        # "SourcingProportions",
        "TransportUncertaintiesParameter1": {},
        "TransportUncertaintiesParameter2": {},
        "TransportUncertaintiesParameter3": {},
        "TransportUncertaintiesParameter4": {},
        "InitialTransportedQuantities": {},
        "InitialTransportedValues": {},
        # "DispatchProportions",
    },
    "Configuration": {
        "ActivateUncertainties": False,
        "ActivateVariableMachineOpeningRate": False,
        "BatchSize": 0,
        "EmptyObsoleteStocks": False,
        "EnforceProductionPlan": False,
        "FinancialCostOfStock": 0,
        "ManageBacklogQuantities": False,
        "OptimizationObjective": "ServiceLevelMaximization",
        "SimulatedCycles": 1,
        # "StartingDate",
        "StepsPerCycle": 1,
        "TimeStepDuration": 1440,
        "UncertaintiesProbabilityDistribution": "Gaussian",
        "IntermediaryStockDispatchPolicy": "DispatchAll",
        "TransportUncertaintiesProbabilityDistribution": "discreteuniform",
        "ActualizeShipments": False,
        "ServeDemandBeforeBacklog": True,
        # "SelectedTimeStep",
        "SelectedTag": "",
        "InventoryQuantityForCostComputation": "Lowest",
        "ActivateCorrelatedDemandUncertainties": False,
        "DemandCorrelations": 0,
        "CarbonTax": 0,
        "Kpi": "Profit",
        "OptimizationMode": "maximize",
        "Statistic": "mean",
        "TargetedValue": 0,
        "DecisionVariable": "FromDataset",
        "DecisionVariableMin": 0,
        "DecisionVariableMax": 10000,
        "OptimizationMaximalDuration": 3600,
        "OptimizationAlgorithm": "NGOpt",
        "OptimizationBatchSize": 1,
        "SampleSizeUncertaintyAnalysis": 15,
        "FinalSampleSizeUncertaintyAnalysis": 1000,
        "MaxIterationsForOptim": 1000,
        "AutomaticParallelizationConfig": True,
        "MaxNumberOfSimInParallel": -1,
        "ConstraintHandling": "None",
        "OptimizationParallelization": -1,
        "UncertaintyAnalysisParallelization": 1,
        "UncertaintyAnalysisSeedForOptimization": -1,
        "UncertaintyAnalysisSeed": -1,
        "OptimizationSeed": -1,
        "UncertaintyAnalysisOutputData": ["Transports", "Stocks", "StocksAtEndOfSimulation", "Performances", "PerformanceAMQP"],
    },
    "OptimizationConstraints": {
        # "id",
        "ConstrainedKpi": "Profit",
        "Statistic": "mean",
        "ConstraintType": "greater_than",
        "ConstraintValue": 0,
        "PenaltyCoefficient": 1,
    },
    "OptimizationDecisionVariables": {
        # "id",
        "SelectedEntity":"",
        "SelectedTag": "",
        #"Attribute",
        #"AttributeMinimumValue",
        #"AttributeMaximumValue",
        "subdataset":"",
    },
    "OptDecisionVariableGroups": {
        # "id",
        # "GroupTag",
        # "Attribute",
        # "GroupBehaviorMode",
        # "DecisionVariableMinimum",
        # "DecisionVariableMaximum",
        # "DecisionVariableStartingPoint"
        "subdataset":"",
    },
    "contains": {
        # "source",
        # "target",
        "subdataset": "",
    },
    "output": {
        # "source",
        # "target",
        "subdataset": "",
    },
    "input": {
        # "source",
        # "target",
        "InputQuantity": 1,
        "subdataset": "",
        # "DispatchProportions",
    },
    "ProductionResource": {
        # "id",
        # "Label",
        "PlantName": "",
        "ProductionStep": "",
        "ProductionPolicy": "Equidistribution",
        "Latitude": 0.0,
        "Longitude": 0.0,
        "subdataset": "",
        "FixedProductionCosts": {},
        # "OpeningTimes",
        "OpeningRates": {},
    },
    "ProductionOperation": {
        # "id",
        # "Label",
        "PlantName": "",
        "IsContractor": False,
        "InvestmentCost": 0,
        "Priority": 0,
        "Duration": 0,
        "subdataset": "",
        "QuantitiesToProduce": {},
        "OperatingPerformances": {},
        "CycleTimes": {},
        "RejectRates": {},
        "OperatingPerformanceUncertainties": {},
        "ProductionUnitCosts": {},
        "CO2UnitEmissions": {},
        "MinimumOrderQuantities": {},
        "MultipleOrderQuantities": {},
        # "SourcingProportions",
        # "ProductionProportions",
    },
    "Tags": {
        # "id",
        "TagType": "",
        "subdataset": "",
    },
    "TagGroups": {
        # "source",
        # "target",
        "subdataset": "",
    },
}
variables_default_values = {
    "Stock": {
        "StorageUnitCosts": 0,
        "OrderPoints": 0,
        "OrderQuantities": 0,
        "OrderUpToLevels": 0,
        "SafetyQuantities": 0,
        "Demands": 0,
        "DemandUncertainties": 0,
        "DemandWeights": 1,
        "SalesForecasts": 0,
        "PurchasingUnitCosts": 0,
        "VariablePurchasingUnitCosts": 0,
        "CO2UnitEmissions": 0,
        "UnitIncomes": 0,
        "RetainProportions": 0,
    },
    "Transport": {
        "CustomFees": 0,
        "TransportUnitCosts": 0,
        "CO2UnitEmissions": 0,
        "ActualDurations": 0,
        "MinimumOrderQuantities": 0,
        "MultipleOrderQuantities": 0,
        "TransportUncertaintiesParameter1": 0,
        "TransportUncertaintiesParameter2": 0,
        "TransportUncertaintiesParameter3": 0,
        "TransportUncertaintiesParameter4": 0,
        "InitialTransportedQuantities": 0,
        "InitialTransportedValues": 0,
        "SourcingProportions": 1,
        "DispatchProportions": 0,
    },
    "Configuration": {},
    "contains": {},
    "output": {},
    "input": {
        "DispatchProportions": 0,
    },
    "ProductionResource": {
        "FixedProductionCosts": 0,
        "OpeningTimes": 1440,
        "OpeningRates": 1,
    },
    "ProductionOperation": {
        "QuantitiesToProduce": 0,
        "OperatingPerformances": 1,
        "CycleTimes": 1,
        "RejectRates": 0,
        "OperatingPerformanceUncertainties": 0,
        "ProductionUnitCosts": 0,
        "CO2UnitEmissions": 0,
        "MinimumOrderQuantities": 0,
        "MultipleOrderQuantities": 0,
        "SourcingProportions": 0,
        "ProductionProportions": 0,
    },
}

==> cosmotech_supplychain-6.2.0.tar.gz: cosmotech_supplychain-6.2.0/Supplychain/Schema/default_values.py <==
parameters_default_values = {
    "Stock": {
        # "id",
        # "Label",
        "PlantName": "",
        "Step": "",
        "PartId": "",
        "MinimalStock": -1,
        "MaximalStock": None,
        # "InitialStock",
        # "InitialValue",
        # "IsInfinite",
        "PurchasingUnitCosts": {},
        "VariablePurchasingUnitCosts": {},
        "CO2UnitEmissions": {},
        "UnitIncomes": {},
        "BacklogWeight": 1,
        "MaximizationWeight": 0,
        "StockPolicy": "None",
        "SourcingPolicy": "Equidistribution",
        "DispatchPolicy": "DispatchProportions",
        "ReviewPeriod": 1,
        "FirstReview": 0,
        "Advance": 0,
        "Latitude": 0.0,
        "Longitude": 0.0,
        "IgnoreDownstreamRequiredQuantities": False,
        "SourcingLimit": "Capacity",
        "InitialBacklog": 0,
        "OrderForEndOfTimeStep": True,
        "subdataset": "",
        "StorageUnitCosts": {},
        "OrderPoints": {},
        "OrderQuantities": {},
        "OrderUpToLevels": {},
        "SafetyQuantities": {},
        "CoverageHorizon": 0,
        "CoverageOffset": 0,
        "CoverageRate": 1,
        "Demands": {},
        "DemandWeights": {},
        "SalesForecasts": {},
        # "RetainProportions",
    },
    "Transport": {
        # "Label",
        # "source",
        # "target",
        # "Duration",
        "Priority": 0,
        "Mode": "",
        "subdataset": "",
        "CustomFees": {},
        "TransportUnitCosts": {},
        "CO2UnitEmissions": {},
        "ActualDurations": {},
        "MinimumOrderQuantities": {},
        "MultipleOrderQuantities": {},
        # "SourcingProportions",
        "InitialTransportedQuantities": {},
        "InitialTransportedValues": {},
        # "DispatchProportions",
    },
    "Configuration": {
        "ActivateUncertainties": [],
        "ActivateVariableMachineOpeningRate": False,
        "BatchSize": 0,
        "EmptyObsoleteStocks": False,
        "EnforceProductionPlan": False,
        "FinancialCostOfStock": 0,
        "ManageBacklogQuantities": False,
        "OptimizationObjective": "ServiceLevelMaximization",
        "SimulatedCycles": 1,
        # "StartingDate",
        "StepsPerCycle": 1,
        "TimeStepDuration": 1440,
        "IntermediaryStockDispatchPolicy": "DispatchAll",
        "ActualizeShipments": False,
        "ServeDemandBeforeBacklog": True,
        # "SelectedTimeStep",
        "SelectedTag": "",
        "InventoryQuantityForCostComputation": "Lowest",
        "CarbonTax": 0,
        "Kpi": "Profit",
        "OptimizationMode": "maximize",
        "Statistic": "mean",
        "TargetedValue": 0,
        "DecisionVariable": "FromDataset",
        "DecisionVariableMin": 0,
        "DecisionVariableMax": 10000,
        "OptimizationMaximalDuration": 3600,
        "OptimizationAlgorithm": "NGOpt",
        "OptimizationBatchSize": 15,
        "SampleSizeUncertaintyAnalysis": 15,
        "FinalSampleSizeUncertaintyAnalysis": 1000,
        "MaxIterationsForOptim": 1000,
        "AutomaticParallelizationConfig": True,
        "MaxNumberOfSimInParallel": -1,
        "ConstraintHandling": "None",
        "OptimizationParallelization": -1,
        "UncertaintyAnalysisParallelization": 1,
        "UncertaintyAnalysisSeedForOptimization": -1,
        "UncertaintyAnalysisSeed": -1,
        "OptimizationSeed": -1,
        "UncertaintyAnalysisOutputData": ["Transports", "Stocks", "StocksAtEndOfSimulation", "Performances", "PerformanceAMQP"],
    },
    "OptimizationConstraints": {
        # "id",
        "ConstrainedKpi": "Profit",
        "Statistic": "mean",
        "ConstraintType": "greater_than",
        "ConstraintValue": 0,
        "PenaltyCoefficient": 1,
    },
    "OptimizationDecisionVariables": {
        # "id",
        "SelectedEntity":"",
        "SelectedTag": "",
        #"Attribute",
        #"AttributeMinimumValue",
        #"AttributeMaximumValue",
        "subdataset":"",
    },
    "OptDecisionVariableGroups": {
        # "id",
        # "GroupTag",
        # "Attribute",
        # "GroupBehaviorMode",
        # "DecisionVariableMinimum",
        # "DecisionVariableMaximum",
        # "DecisionVariableStartingPoint"
        "subdataset":"",
    },
    "contains": {
        # "source",
        # "target",
        "subdataset": "",
    },
    "output": {
        # "source",
        # "target",
        "subdataset": "",
    },
    "input": {
        # "source",
        # "target",
        "InputQuantity": 1,
        "subdataset": "",
        # "DispatchProportions",
    },
    "ProductionResource": {
        # "id",
        # "Label",
        "PlantName": "",
        "ProductionStep": "",
        "ProductionPolicy": "Equidistribution",
        "Latitude": 0.0,
        "Longitude": 0.0,
        "subdataset": "",
        "FixedProductionCosts": {},
        # "OpeningTimes",
        "OpeningRates": {},
    },
    "ProductionOperation": {
        # "id",
        # "Label",
        "PlantName": "",
        "IsContractor": False,
        "InvestmentCost": 0,
        "Priority": 0,
        "Duration": 0,
        "subdataset": "",
        "QuantitiesToProduce": {},
        "OperatingPerformances": {},
        "CycleTimes": {},
        "RejectRates": {},
        "ProductionUnitCosts": {},
        "CO2UnitEmissions": {},
        "MinimumOrderQuantities": {},
        "MultipleOrderQuantities": {},
        # "SourcingProportions",
        # "ProductionProportions",
    },
    "Tags": {
        # "id",
        "TagType": "",
        "subdataset": "",
    },
    "TagGroups": {
        # "source",
        # "target",
        "subdataset": "",
    },
    "Uncertainties": {
        # "Entity",
        # "Attribute",
        "TimeStep": -1,
        # "UncertaintyMode",
        # "UncertaintyModel",
        # "Parameters",
    },
}
variables_default_values = {
    "Stock": {
        "StorageUnitCosts": 0,
        "OrderPoints": 0,
        "OrderQuantities": 0,
        "OrderUpToLevels": 0,
        "SafetyQuantities": 0,
        "Demands": 0,
        "DemandWeights": 1,
        "SalesForecasts": 0,
        "PurchasingUnitCosts": 0,
        "VariablePurchasingUnitCosts": 0,
        "CO2UnitEmissions": 0,
        "UnitIncomes": 0,
        "RetainProportions": 0,
    },
    "Transport": {
        "CustomFees": 0,
        "TransportUnitCosts": 0,
        "CO2UnitEmissions": 0,
        "ActualDurations": 0,
        "MinimumOrderQuantities": 0,
        "MultipleOrderQuantities": 0,
        "InitialTransportedQuantities": 0,
        "InitialTransportedValues": 0,
        "SourcingProportions": 1,
        "DispatchProportions": 0,
    },
    "Configuration": {},
    "contains": {},
    "output": {},
    "input": {
        "DispatchProportions": 0,
    },
    "ProductionResource": {
        "FixedProductionCosts": 0,
        "OpeningTimes": 1440,
        "OpeningRates": 1,
    },
    "ProductionOperation": {
        "QuantitiesToProduce": 0,
        "OperatingPerformances": 1,
        "CycleTimes": 1,
        "RejectRates": 0,
        "ProductionUnitCosts": 0,
        "CO2UnitEmissions": 0,
        "MinimumOrderQuantities": 0,
        "MultipleOrderQuantities": 0,
        "SourcingProportions": 0,
        "ProductionProportions": 0,
    },
}
